@@ -73,6 +73,7 @@
 
 
 MODULE_TYPE_INPUT
+MODULE_TYPE_NOKEEP
 
 /* static data */
 DEF_IMOD_STATIC_DATA
@@ -1046,17 +1047,20 @@ CODESTARTwillRun
 		ABORT_FINALIZE(RS_RET_NO_RUN);
 	}
 
-#	if defined(EPOLL_CLOEXEC) && defined(HAVE_EPOLL_CREATE1)
-		DBGPRINTF("imptcp uses epoll_create1()\n");
-		epollfd = epoll_create1(EPOLL_CLOEXEC);
-#	else
+#if defined(EPOLL_CLOEXEC) && defined(HAVE_EPOLL_CREATE1)
+	DBGPRINTF("imptcp uses epoll_create1()\n");
+	epollfd = epoll_create1(EPOLL_CLOEXEC);
+	if(epollfd < 0 && errno == ENOSYS)
+#endif
+	{
 		DBGPRINTF("imptcp uses epoll_create()\n");
 		/* reading the docs, the number of epoll events passed to
 		 * epoll_create() seems not to be used at all in kernels. So
 		 * we just provide "a" number, happens to be 10.
 		 */
 		epollfd = epoll_create(10);
-#	endif
+	}
+
 	if(epollfd < 0) {
 		errmsg.LogError(0, RS_RET_EPOLL_CR_FAILED, "error: epoll_create() failed");
 		ABORT_FINALIZE(RS_RET_NO_RUN);
