@@ -33,6 +33,8 @@
  */
 #ifndef INCLUDED_ATOMIC_H
 #define INCLUDED_ATOMIC_H
+#include <time.h>
+#include "typedefs.h"
 
 /* for this release, we disable atomic calls because there seem to be some
  * portability problems and we can not fix that without destabilizing the build.
@@ -42,7 +44,8 @@
 #	define ATOMIC_SUB(data, val, phlpmut) __sync_fetch_and_sub(data, val)
 #	define ATOMIC_ADD(data, val) __sync_fetch_and_add(&(data), val)
 #	define ATOMIC_INC(data, phlpmut) ((void) __sync_fetch_and_add(data, 1))
-#	define ATOMIC_INC_AND_FETCH(data, phlpmut) __sync_fetch_and_add(data, 1)
+#	define ATOMIC_INC_AND_FETCH_int(data, phlpmut) __sync_fetch_and_add(data, 1)
+#	define ATOMIC_INC_AND_FETCH_unsigned(data, phlpmut) __sync_fetch_and_add(data, 1)
 #	define ATOMIC_DEC(data, phlpmut) ((void) __sync_sub_and_fetch(data, 1))
 #	define ATOMIC_DEC_AND_FETCH(data, phlpmut) __sync_sub_and_fetch(data, 1)
 #	define ATOMIC_FETCH_32BIT(data, phlpmut) ((unsigned) __sync_fetch_and_and(data, 0xffffffff))
@@ -51,6 +54,7 @@
 #	define ATOMIC_STORE_1_TO_INT(data, phlpmut) __sync_fetch_and_or(data, 1)
 #	define ATOMIC_STORE_INT_TO_INT(data, val) __sync_fetch_and_or(&(data), (val))
 #	define ATOMIC_CAS(data, oldVal, newVal, phlpmut) __sync_bool_compare_and_swap(data, (oldVal), (newVal))
+#	define ATOMIC_CAS_time_t(data, oldVal, newVal, phlpmut) __sync_bool_compare_and_swap(data, (oldVal), (newVal))
 #	define ATOMIC_CAS_VAL(data, oldVal, newVal, phlpmut) __sync_val_compare_and_swap(data, (oldVal), (newVal));
 
 	/* functions below are not needed if we have atomics */
@@ -104,6 +108,20 @@
 		return(bSuccess);
 	}
 
+	static inline int
+	ATOMIC_CAS_time_t(time_t *data, time_t oldVal, time_t newVal, pthread_mutex_t *phlpmut) {
+		int bSuccess;
+		pthread_mutex_lock(phlpmut);
+		if(*data == oldVal) {
+			*data = newVal;
+			bSuccess = 1;
+		} else {
+			bSuccess = 0;
+		}
+		pthread_mutex_unlock(phlpmut);
+		return(bSuccess);
+	}
+
 
 	static inline int
 	ATOMIC_CAS_VAL(int *data, int oldVal, int newVal, pthread_mutex_t *phlpmut) {
@@ -124,7 +142,7 @@
 	}
 
 	static inline int
-	ATOMIC_INC_AND_FETCH(int *data, pthread_mutex_t *phlpmut) {
+	ATOMIC_INC_AND_FETCH_int(int *data, pthread_mutex_t *phlpmut) {
 		int val;
 		pthread_mutex_lock(phlpmut);
 		val = ++(*data);
@@ -132,6 +150,15 @@
 		return(val);
 	}
 
+	static inline unsigned
+	ATOMIC_INC_AND_FETCH_unsigned(unsigned *data, pthread_mutex_t *phlpmut) {
+		unsigned val;
+		pthread_mutex_lock(phlpmut);
+		val = ++(*data);
+		pthread_mutex_unlock(phlpmut);
+		return(val);
+	}
+
 	static inline int
 	ATOMIC_DEC_AND_FETCH(int *data, pthread_mutex_t *phlpmut) {
 		int val;
@@ -156,11 +183,6 @@
 		(*data) -= val;
 		pthread_mutex_unlock(phlpmut);
 	}
-#if 0
-#	warning "atomic builtins not available, using nul operations - rsyslogd will probably be racy!"
-#	define ATOMIC_INC_AND_FETCH(data) (++(data))
-#	define ATOMIC_STORE_1_TO_32BIT(data) (data) = 1 // TODO: del
-#endif
 #	define DEF_ATOMIC_HELPER_MUT(x)  pthread_mutex_t x
 #	define INIT_ATOMIC_HELPER_MUT(x) pthread_mutex_init(&(x), NULL)
 #	define DESTROY_ATOMIC_HELPER_MUT(x) pthread_mutex_destroy(&(x))
@@ -169,4 +191,41 @@
 
 #endif
 
+/* we need to handle 64bit atomics seperately as some platforms have 
+ * 32 bit atomics, but not 64 biot ones... -- rgerhards, 2010-12-01
+ */
+#ifdef HAVE_ATOMIC_BUILTINS_64BIT
+#	define ATOMIC_INC_uint64(data, phlpmut) ((void) __sync_fetch_and_add(data, 1))
+#	define ATOMIC_DEC_unit64(data, phlpmut) ((void) __sync_sub_and_fetch(data, 1))
+#	define ATOMIC_INC_AND_FETCH_uint64(data, phlpmut) __sync_fetch_and_add(data, 1)
+
+#	define DEF_ATOMIC_HELPER_MUT64(x)
+#	define INIT_ATOMIC_HELPER_MUT64(x)
+#	define DESTROY_ATOMIC_HELPER_MUT64(x) 
+#else
+#	define ATOMIC_INC_uint64(data, phlpmut)  { \
+		pthread_mutex_lock(phlpmut); \
+		++(*(data)); \
+		pthread_mutex_unlock(phlpmut); \
+	}
+#	define ATOMIC_DEC_uint64(data, phlpmut)  { \
+		pthread_mutex_lock(phlpmut); \
+		--(*(data)); \
+		pthread_mutex_unlock(phlpmut); \
+	}
+
+	static inline unsigned
+	ATOMIC_INC_AND_FETCH_uint64(uint64 *data, pthread_mutex_t *phlpmut) {
+		uint64 val;
+		pthread_mutex_lock(phlpmut);
+		val = ++(*data);
+		pthread_mutex_unlock(phlpmut);
+		return(val);
+	}
+
+#	define DEF_ATOMIC_HELPER_MUT64(x)  pthread_mutex_t x
+#	define INIT_ATOMIC_HELPER_MUT64(x) pthread_mutex_init(&(x), NULL)
+#	define DESTROY_ATOMIC_HELPER_MUT64(x) pthread_mutex_destroy(&(x))
+#endif /* #ifdef HAVE_ATOMIC_BUILTINS_64BIT */
+
 #endif /* #ifndef INCLUDED_ATOMIC_H */
