@@ -110,30 +110,17 @@ rsRetVal getFileSize(uchar *pszName, off_t *pSize);
 
 /* some useful constants */
 #define DEFVARS_mutexProtection\
-	int iCancelStateSave; \
 	int bLockedOpIsLocked=0
 #define BEGIN_MTX_PROTECTED_OPERATIONS(mut, bMustLock) \
 	if(bMustLock == LOCK_MUTEX) { \
-		pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, &iCancelStateSave); \
 		d_pthread_mutex_lock(mut); \
+		assert(bLockedOpIsLocked == 0); \
 		bLockedOpIsLocked = 1; \
 	}
 #define END_MTX_PROTECTED_OPERATIONS(mut) \
 	if(bLockedOpIsLocked) { \
 		d_pthread_mutex_unlock(mut); \
-		pthread_setcancelstate(iCancelStateSave, NULL); \
+		bLockedOpIsLocked = 0; \
 	}
 
-/* The unconditional versions of the macro always lock the mutex. They are preferred in 
- * complex scenarios, where the simple ones might get mixed up by multiple calls.
- */
-#define DEFVARS_mutexProtection_uncond\
-	int iCancelStateSave
-#define BEGIN_MTX_PROTECTED_OPERATIONS_UNCOND(mut) \
-	pthread_setcancelstate(PTHREAD_CANCEL_DISABLE, &iCancelStateSave); \
-	d_pthread_mutex_lock(mut); 
-#define END_MTX_PROTECTED_OPERATIONS_UNCOND(mut) \
-	d_pthread_mutex_unlock(mut); \
-	pthread_setcancelstate(iCancelStateSave, NULL);
-
 #endif
