@@ -56,7 +56,10 @@
  * applications I do not yet envision. -- rgerhards, 2007-07-24
  */
 typedef enum _syslogFeature {
-	sFEATURERepeatedMsgReduction = 1
+	sFEATURERepeatedMsgReduction = 1,	/* for output modules */
+	sFEATURENonCancelInputTermination = 2,	/* for input modules */
+	sFEATUREAutomaticSanitazion = 3,	/* for parser modules */
+	sFEATUREAutomaticPRIParsing = 4		/* for parser modules */
 } syslogFeature;
 
 /* we define our own facility and severities */
