@@ -26,6 +26,7 @@
 
 #include <pthread.h>
 #include "obj.h"
+#include "atomic.h"
 
 /* states for worker threads. */
 #define WRKTHRD_STOPPED  FALSE
@@ -65,6 +66,8 @@ struct wtp_s {
 	rsRetVal (*pfDoWork)(void *pUsr, void *pWti);
 	/* end user objects */
 	uchar *pszDbgHdr;	/* header string for debug messages */
+	DEF_ATOMIC_HELPER_MUT(mutCurNumWrkThrd);
+	DEF_ATOMIC_HELPER_MUT(mutWtpState);
 };
 
 /* some symbolic constants for easier reference */
