@@ -60,8 +60,6 @@ DEFobjCurrIf(datetime)
 
 static int iMaxLine; /* maximum size of a single message */
 
-static int iNbrTimeUsed = 0;		    /* how often has previous time been used so far? */
-
 
 /* forward definitions */
 static rsRetVal Close(tcps_sess_t *pThis);
@@ -241,6 +239,11 @@ defaultDoSubmitMessage(tcps_sess_t *pThis, struct syslogTime *stTime, time_t ttG
 
 	ISOBJ_TYPE_assert(pThis, tcps_sess);
 	
+	if(pThis->iMsg == 0) {
+		DBGPRINTF("discarding zero-sized message\n");
+		FINALIZE;
+	}
+
 	if(pThis->DoSubmitMessage != NULL) {
 		pThis->DoSubmitMessage(pThis, pThis->pMsg, pThis->iMsg);
 		FINALIZE;
@@ -407,7 +410,7 @@ processDataRcvd(tcps_sess_t *pThis, char c, struct syslogTime *stTime, time_t tt
 			 */
 		}
 
-		if((   (c == '\n')
+		if((   ((c == '\n') && !pThis->pSrv->bDisableLFDelim)
 		   || ((pThis->pSrv->addtlFrameDelim != TCPSRV_NO_ADDTL_DELIMITER) && (c == pThis->pSrv->addtlFrameDelim))
 		   ) && pThis->eFraming == TCP_FRAMING_OCTET_STUFFING) { /* record delimiter? */
 			defaultDoSubmitMessage(pThis, stTime, ttGenTime, pMultiSub);
@@ -475,13 +478,14 @@ DataRcvd(tcps_sess_t *pThis, char *pData, size_t iLen)
 	 /* We now copy the message to the session buffer. */
 	pEnd = pData + iLen; /* this is one off, which is intensional */
 
-	iNbrTimeUsed = 0; /* full time query */
 	while(pData < pEnd) {
 		CHKiRet(processDataRcvd(pThis, *pData++, &stTime, ttGenTime, &multiSub));
 	}
 
-	/* submit anything that was not yet submitted */
-	CHKiRet(multiSubmitMsg(&multiSub));
+	if(multiSub.nElem > 0) {
+		/* submit anything that was not yet submitted */
+		CHKiRet(multiSubmitMsg(&multiSub));
+	}
 
 finalize_it:
 	RETiRet;
